@@ -2,37 +2,28 @@ from __future__ import annotations
 
 import datetime
 import re
-import copy
+import importlib
 
 from dateutil.parser import parse as parse_dt, isoparse
 
-from yankee.util import clean_whitespace, is_valid
+from yankee.util import AttrDict, clean_whitespace, is_valid
 
 from .deserializer import Deserializer
 from .schema import Schema
 
 
 class Field(Deserializer):
-    def __init__(self, data_key=None, required=False, many=False):
-        super().__init__(data_key=data_key, required=required)
-        self.required = required
-
-    def deserialize(self, obj):
-        if obj is None and self.required:
-            raise ValueError(
-                f"Field {self.name} is required! Key {self.key} not found in {obj}"
-            )
-        return obj
-
+    pass
 
 class String(Field):
-    def __init__(self, data_key=None, required=False, attr=None, formatter=None):
-        super().__init__(data_key, required)
+    def __init__(self, *args, formatter=None, null_value=None, **kwargs):
+        super().__init__(*args, **kwargs)
         self.formatter = formatter or clean_whitespace
+        self.null_value = null_value
 
     def deserialize(self, elem) -> "Optional[str]":
         elem = super().deserialize(elem)
-        if elem is None:
+        if elem is None or elem == "" or elem == self.null_value:
             return None
         else:
             return self.formatter(self.to_string(elem))
@@ -42,10 +33,8 @@ class String(Field):
 
 
 class DateTime(String):
-    def __init__(
-        self, data_key=None, required=False, attr=None, formatter=None, dt_format=None
-    ):
-        super().__init__(data_key, required, attr, formatter)
+    def __init__(self, *args, dt_format=None, **kwargs):
+        super().__init__(*args, **kwargs)
         if dt_format:
             self.parse_date = lambda s: datetime.datetime.strptime(s, dt_format)
 
@@ -57,9 +46,7 @@ class DateTime(String):
 
     def deserialize(self, elem) -> "Optional[datetime.datetime]":
         string = super(DateTime, self).deserialize(elem)
-        if not string:
-            return None
-        return self.parse_date(string)      
+        return self.parse_date(string) if string else None
 
 
 
@@ -109,17 +96,38 @@ class Exists(Field):
 
 class Const(Field):
     def __init__(self, const, *args, **kwargs):
+        super().__init__(self, *args, **kwargs)
         self.const = const
 
     def deserialize(self, elem) -> "Any":
         return self.const
-
+    
 
 # Multiple Value Fields
-class List(Field):
-    many = True
+    
+class Nested(Field):
+    def __init__(self, schema, data_key=None, *args, **kwargs):
+        self._schema = schema
+        self._args = args
+        self._kwargs = kwargs
+        super().__init__(data_key, *args, **kwargs)
 
-    def __init__(self, item_schema, data_key, **kwargs):
+    def bind(self, name=None, schema=None):
+        super().bind(name, schema)
+        if isinstance(self._schema, str):
+            *module, _schema = self._schema.split(".")
+            module = ".".join(module) or schema.__module__
+            self._schema_class = getattr(importlib.import_module(module), self._schema)
+        else:
+            self._schema_class = self._schema
+        self._schema_obj = self._schema_class(*self._args, **self._kwargs)
+
+    def load(self, obj):
+        return self._schema_obj.load(obj)
+
+class List(Field):
+    def __init__(self, item_schema, data_key=None, **kwargs):
+        kwargs['many'] = True
         self.item_schema = item_schema
         if callable(self.item_schema):
             self.item_schema = item_schema()
@@ -127,13 +135,20 @@ class List(Field):
 
     def bind(self, name=None, schema=None):
         super().bind(name, schema)
+        if isinstance(self.item_schema, str):
+            *module, _schema = self.item_schema.split(".")
+            module = ".".join(module) or schema.__module__
+            self.item_schema = getattr(importlib.import_module(module), self.item_schema)()
         self.item_schema.bind(None, schema)
 
     def deserialize(self, obj):
+        obj = super().deserialize(obj)
+        if not obj:
+            return list()
         obj_gen = (self.item_schema.load(i) for i in obj)
         return [o for o in obj_gen if is_valid(o)]
 
-class Dict(List):
+class Dictionary(List):
     """Converts a list of items into a dictionary based on
     the key and value fields passed to it.
     """
@@ -145,7 +160,7 @@ class Dict(List):
     
     def deserialize(self, obj):
         obj = super().deserialize(obj)
-        return {self.key.load(i):self.value.load(i) for i in obj}
+        return AttrDict((self.key.load(i), self.value.load(i)) for i in obj)
 
 # String Parsing Fields
 
@@ -170,8 +185,6 @@ class DelimitedString(String):
         objs = (self.item_schema.load(o) for o in self.delimeter.split(obj))
         return [o for o in objs if is_valid(o)]
 
-
-
 # Schema-Like Fields
 
 class Combine(Schema):
@@ -201,35 +214,10 @@ class Alternative(Schema):
         return next((v for v in obj.values() if is_valid(v)), None)
 
 
-class ZipSchema(Schema):
-    _list_field = List
-    """Sometimes data is provided as a bunch of arrays, like:
-    {
-        "name": ["Peter", "Parker"],
-        "age": [15, 25],
-    }
-    and we want to build out complete records from this data.
-    This field performs that step:
-    """
-
-    def bind(self, name=None, parent=None):
-        super().bind(name, parent)
-        zip_fields = dict()
-        for k, v in self.fields.items():
-            v_copy = copy.deepcopy(v)
-            # Remove the data key
-            data_key = v_copy.data_key
-            v_copy.data_key = None
-            # Place it on the list field
-            zip_fields[k] = self._list_field(v_copy, data_key)
-        self.unzip_fields = self.fields
-        self.fields = zip_fields
-
-    def deserialize(self, obj) -> "Dict":
-        objs = super().deserialize(obj)
-        return self.lists_to_records(objs)
-    
-    def lists_to_records(self, obj):
-        keys = tuple(obj.keys())
-        values = tuple(obj.values())
-        return [dict(zip(keys, v)) for v in zip(*values)]
+# Aliases
+Str = String
+DT = DateTime
+Bool = Boolean
+Int = Integer
+Alt = Alternative
+Dict = Dictionary
\ No newline at end of file
