@@ -1,6 +1,7 @@
 import re
+from yankee.io.convert import jsonify, pythonify
 
-from yankee.util import camelize, underscore, is_valid
+from yankee.util import camelize, underscore, is_valid, AttrDict, clean_whitespace, unzip_records
 
 from .deserializer import Deserializer
 
@@ -23,14 +24,15 @@ class Schema(Deserializer):
 
     def __init__(
         self,
-        data_key=None,
+        *args,
         flatten=False,
         prefix=False,
-        required=False,
+        **kwargs
     ):
         self.flatten = flatten
         self.prefix = prefix
-        super().__init__(data_key, required)
+        super().__init__(*args, **kwargs)
+        self.bind()
 
     def bind(self, name=None, parent=None):
         super().bind(name, parent)
@@ -43,7 +45,7 @@ class Schema(Deserializer):
         fields = dict(class_fields)
         for name, field in fields.items():
             field.bind(name, self)
-        self.fields = {self.get_output_name(k): v for k, v in fields.items()}
+        self.fields = fields
 
     def get_output_name(self, name):
         output_style = getattr(self.Meta, "output_style", None)
@@ -61,13 +63,11 @@ class Schema(Deserializer):
             return name
 
     def deserialize(self, obj) -> "Dict":
-        output = dict()
+        output = AttrDict()
         for key, field in self.fields.items():
             value = field.load(obj)
             # If there is no value, don't include anything in the output dictionary
             if not is_valid(value):
-                if field.required == True:
-                    return dict()
                 continue
             # If the value isn't a dict, or there's not flatten directive, add and continue
             if not isinstance(value, dict) or not getattr(field, "flatten", False):
@@ -77,6 +77,15 @@ class Schema(Deserializer):
             output.update(value)
         return output
 
+    def load(self, obj):
+        out = super().load(obj)
+        if not hasattr(self.Meta, "output_style") or self.Meta.output_style == None:
+            return out
+        elif self.Meta.output_style == "json":
+            return jsonify(out)
+        elif self.Meta.output_style == "python":
+            return pythonify(out)
+
 
 class PolymorphicSchema(Schema):
     def bind(self, name=None):
@@ -109,7 +118,7 @@ class RegexSchema(Schema):
     def deserialize(self, obj):
         if obj is None:
             return None
-        text = self.to_string(obj)
+        text = clean_whitespace(self.to_string(obj))
         match = self._regex.search(text)
         if match is None:
             return None
@@ -117,4 +126,20 @@ class RegexSchema(Schema):
         return super().deserialize(data)
     
     def convert_groupdict(self, obj):
-        return obj
\ No newline at end of file
+        return obj
+
+class ZipSchema(Schema):
+    """
+    This schema type allows fields that produce multiple values to be
+    zipped together into records.
+    """
+    def bind(self, name=None, parent=None):
+        super().bind(name, parent)
+        new_fields = dict()
+        for name, field in self.fields.items():
+            new_fields[name] = f.List(field.__class__, getattr(field.accessor, "data_key", None))
+        self.fields = new_fields
+
+    def deserialize(self, obj) -> "Dict":
+        result = unzip_records(super().deserialize(obj))
+        return result
\ No newline at end of file
