@@ -1,3 +1,4 @@
+import lxml.etree as ET
 from yankee.base import fields
 
 from .key import XmlMixin
@@ -48,14 +49,9 @@ class Dict(XmlMixin, fields.Dict):
 class Combine(XmlMixin, fields.Combine):
     pass
 
-
 class Alternative(XmlMixin, fields.Alternative):
     pass
 
-
-class ZipSchema(XmlMixin, fields.ZipSchema):
-    _list_field = List
-
 class DelimitedString(XmlMixin, fields.DelimitedString):
     pass
 
