@@ -49,9 +49,13 @@ test_doc = """
 
 tree = ET.fromstring(test_doc.encode())
 
-class NameZipSchema(f.ZipSchema):
-    first_name = f.Str("./zip/first_name/name")
-    last_name = f.Str("./zip/last_name/name")
+class NameCombineSchema(f.Combine):
+    first_name = f.Str(".//first_name/name")
+    last_name = f.Str(".//last_name/name")
+
+    def combine_func(self, obj):
+        return f"{obj.first_name} {obj.last_name}"
+
 class NameSchema(Combine):
     part1 = f.Str(".//part1")
     part2 = f.Str(".//part2")
@@ -83,7 +87,20 @@ class ExampleSchema(Schema):
     gone = f.Str("./nonexistent_path")
     csv = f.DelimitedString(f.Str(), data_key="./csv", delimeter=",")
     dict = f.Dict("./dict/item", key=f.Str(".//@name"), value=f.Str())
-    zip = NameZipSchema()
+
+
+def test_element_filter():
+    doc = """<list>
+    <el attr="no"/>
+    <el attr="yes">This One!</el>
+    </list>"""
+
+    tree = ET.fromstring(doc.encode("utf-8"))
+    class ListSchema(Schema):
+        el = f.Str(".//el", filter=lambda e: e.attrib['attr'] == "yes")
+
+    assert ListSchema().load(tree).el == "This One!"
+
 
 
 
@@ -107,11 +124,8 @@ def test_fields():
         "key1": "value1",
         "key2": "value2",
     }
-    assert data['zip'] == [
-        {"first_name": "Parker", "last_name": "Hancock"},
-        {"first_name": "Peter", "last_name": "Parker"}
-    ]
     assert data['comment'] == "A Comment"
+    assert data.string == "Some String Data"
 
 ns_test_doc = """
 <?xml version='1.0' encoding='UTF-8'?>
@@ -147,3 +161,17 @@ def test_ns_fields():
     assert data["date_time"] == datetime.datetime(2021, 5, 4, 12, 5)
     assert data["date"] == datetime.date(2021, 5, 4)
     assert data["booleans"] == [True, True, False, False]
+
+def test_missing_field():
+    doc = b"""<doc><name><first_name>Parker</first_name></name></doc>"""
+    tree = ET.fromstring(doc)
+
+    class NameSchema(Schema):
+        first_name = f.Str("./first_name")
+        last_name = f.Str("./last_name")
+
+    class ExampleSchema(Schema):
+        name = NameSchema("./name_1")
+
+    result = ExampleSchema().load(tree)
+    assert result == dict()
